@@ -2,10 +2,10 @@
 from os import path
 from sys import modules
 
-__version__ = "7.0.0"
+__version__ = "7.0.6"
 AUTHOR = "Kerem Koseoglu"
 EMAIL = "kerem@keremkoseoglu.com"
-DESCRIPTION = "Databus is a framework to transfer data between systems."
+DESCRIPTION = "Databus is a middleware framework"
 PYTHON_VERSION = ">=3.6.5"
 
 
